shithub: pokered

Download patch

ref: cdcf80630fcf4b405e735560d1a61cf573a9319e
parent: 930417ae3b0e310e7fe2300fb3a1a3a169509636
author: Bryan Bishop <kanzure@gmail.com>
date: Thu Mar 15 20:08:58 EDT 2012

romvisualizer updates for main.asm, common.asm, pokered.asm

hg-commit-id: cc4f5c666710


--- a/extras/analyze_incbins.py
+++ b/extras/analyze_incbins.py
@@ -27,9 +27,23 @@
     return int(offset) % 0x4000 + 0x4000
 
 def load_asm(filename="../main.asm"):
-    "loads the asm source code into memory"
+    """loads the asm source code into memory
+    this also detects if the revision of the repository
+    is using main.asm, common.asm or pokered.asm, which is
+    useful when generating images in romvisualizer.py"""
     global asm
-    asm = open(filename, "r").read().split("\n")
+    defaults = ["../main.asm", "../common.asm", "../pokered.asm"]
+    if filename in defaults:
+        if os.path.exists("../main.asm"):
+            asm = open("../main.asm", "r").read().split("\n")
+        elif os.path.exists("../common.asm"):
+            asm = open("../common.asm", "r").read().split("\n")
+        elif os.path.exists("../pokered.asm"):
+            asm = open("../pokered.asm", "r").read().split("\n")
+        else:
+            raise "this shouldn't happen"
+    else:
+        asm = open(filename, "r").read().split("\n")
     return asm
 
 def isolate_incbins():
--- a/extras/romviz.py
+++ b/extras/romviz.py
@@ -33,8 +33,8 @@
     end = incbin["end"]
 
     for pos in range(start, end+1):
-        widthx = pos % width
-        heighty = floor(pos / height)
+        widthx = int(pos % width)
+        heighty = int(floor(pos / height))
         im.putpixel((widthx, heighty), 1)
 
 im.save("test.png")
--- a/extras/romvisualizer.py
+++ b/extras/romvisualizer.py
@@ -2,7 +2,7 @@
 #date: 2012-01-13
 import os
 
-changeset_numbers = range(266, 635)
+changeset_numbers = range(1145, 1149)
 
 def take_snapshot_image(changeset_number):
     "turn main.asm into an image at a certain version"
@@ -9,8 +9,10 @@
 
     print "reverting main.asm to r" + str(changeset_number)
 
     #revert the file
     os.system("hg revert ../main.asm -r" + str(changeset_number))
+    os.system("hg revert ../common.asm -r" + str(changeset_number))
+    os.system("hg revert ../pokered.asm -r" + str(changeset_number))
 
     print "generating the image.."
 
@@ -9,8 +9,10 @@
     print "reverting main.asm to r" + str(changeset_number)
 
-    #revert the file
+    #revert the file (it used to be common.asm)
     os.system("hg revert ../main.asm -r" + str(changeset_number))